/************************************************************************/
/* comm_portable.c- Portability Source                                 */
/************************************************************************/
/*
 *  (c)2008 Todd Shadburn
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
/************************************************************************/

#include <fcntl.h>
#include <errno.h>

#include <comm/comm_portable.h>


/* BEGIN: w32 portable function declarations */
#ifdef WIN32

int portable_fcntl (int fd, int cmd, long arg)
{
	int	rc;
	if (fd == -1)
		return EBADF;
	switch (cmd) {
		case F_SETFL:
			rc = ioctlsocket ((SOCKET)fd, FIONBIO, &arg);
			if (rc == SOCKET_ERROR)
				rc = GetLastError ();
			break;
		default:
			rc = EINVAL;
	}
	return rc;
}


int portable_pipe (int filedes[2])
{
	int	rc;
	if (filedes == NULL)
		return EINVAL;
	rc = CreatePipe ((PHANDLE)&filedes[0], (PHANDLE)&filedes[1], NULL, 0);
	if (rc == 0)
		return GetLastError();
	return 0;
}

#endif
/* END: w32 portable function declarations */


